@@ -82,6 +82,7 @@ class XLSXRenderer(BaseRenderer):
     boolean_labels = None
     date_format_mappings = None
     custom_mappings = None
+    custom_cols = None
     sanitize_fields = True  # prepend possibly malicious values with "'"
 
     def render(self, data, accepted_media_type=None, renderer_context=None):
@@ -135,12 +136,20 @@ class XLSXRenderer(BaseRenderer):
             # I.e.: xlsx_boolean_labels: {True: "Yes", False: "No"}
             self.boolean_display = getattr(drf_view, "xlsx_boolean_labels", None)
 
-            # set dict named xlsx_date_format_mappings with headers as keys and
+            # Set dict named xlsx_date_format_mappings with headers as keys and
             # formatting as value. i.e. { 'created_at': '%d.%m.%Y, %H:%M' }
             self.date_format_mappings = getattr(
                 drf_view, "xlsx_date_format_mappings", None
             )
 
+            # Set dict of additional columns. Can be useful when wanting to add columns
+            # that don't exist in the API response. For example, you could want to
+            # show values of a dict in individidual cols. Takes key, an optional label 
+            # and value than can be callable
+            # Example:
+            # {"Additional Col": { label: "Something (optional)", value: my_function }}
+            self.custom_cols = getattr(drf_view, "xlsx_custom_cols", None)
+
             # Map a specific key to a column (I.e. if the field returns a json) or pass
             # a function to format the value
             # Example with key:
@@ -149,13 +158,21 @@ class XLSXRenderer(BaseRenderer):
             # Example with function:
             # {"custom_choice": custom_func }, passing the value of 'custom_choice' to
             # 'custom_func', allowing for formatting logic
-            self.custom_mappings = getattr(drf_view, "xlsx_custom_mappings", None)
+            self.custom_mappings = getattr(drf_view, "xlsx_custom_mappings", dict())
 
             self.xlsx_header_dict = self._flatten_serializer_keys(
                 drf_view.get_serializer(), use_labels=use_labels
             )
 
-            for column_name, column_label in self.xlsx_header_dict.items():
+            custom_header_dict = {
+                key: self.custom_cols[key].get('label', None) or key 
+                for key in self.custom_cols.keys()
+            }
+            self.combined_header_dict = dict(
+                list(self.xlsx_header_dict.items()) + list(custom_header_dict.items())
+            )
+
+            for column_name, column_label in self.combined_header_dict.items():
                 if column_name == "row_color":
                     continue
                 column_count += 1
@@ -269,6 +286,7 @@ class XLSXRenderer(BaseRenderer):
                     _header_dict[new_key] = _get_label(parent_label, label_sep, v)
                 else:
                     _header_dict[new_key] = new_key
+
         return _header_dict
 
     def _flatten_data(self, data, parent_key="", key_sep=".", list_sep=", "):
@@ -291,6 +309,15 @@ class XLSXRenderer(BaseRenderer):
                     _append_item(new_key, v.get(custom_mapping))
                 elif callable(custom_mapping):
                     _append_item(new_key, custom_mapping(v))
+            elif self.custom_cols and new_key in self.custom_cols:
+                custom_col_value = self.custom_cols[new_key].get('formatter', None)
+                val = v
+                if custom_col_value and callable(custom_col_value):
+                    val = custom_col_value(v)
+                if self.boolean_display and type(val) is bool:
+                    _append_item(new_key, str(self.boolean_display.get(val, val)))
+                else:
+                    _append_item(new_key, val)
             elif isinstance(v, MutableMapping):
                 items.extend(self._flatten_data(v, new_key, key_sep=key_sep).items())
             elif isinstance(v, Iterable) and not isinstance(v, str):
@@ -319,7 +346,7 @@ class XLSXRenderer(BaseRenderer):
         column_count = 0
         row_count += 1
         flattened_row = self._flatten_data(row)
-        for header_key in self.xlsx_header_dict:
+        for header_key in self.combined_header_dict:
             if header_key == "row_color":
                 continue
             column_count += 1
